
local GreatLadder = ...

-- Register great ladder prefab nodes
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/CenterPart", _BridgePrefix .. "_CENTER_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/RootPart", _BridgePrefix .. "_CENTER_ROOT_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/StartPart", _BridgePrefix .. "_START_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/EndPart", _BridgePrefix .. "_END_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/StartSlopePart", _BridgePrefix .. "_SLOPE_START_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/EndSlopePart", _BridgePrefix .. "_SLOPE_END_PREFAB")
GreatLadder:registerAssetId("models/greatLadder3.fbx/Prefab/greatLadder/TilingPart", _BridgePrefix .. "_TILING_PREFAB")

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    GreatLadder:log("Hello World: game version anterior to 1.6")
    _MoverStart = "BUILDING_PART_MOVER"
    _MoverCore = "BUILDING_PART_MOVER_BRIDGE"
    _ConstructorDataStart = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = _BridgePrefix .. "_START_PREFAB",
		FillerList = {
			_BridgePrefix .. "_TILING_PART"
		},
		BasementScale = 2
    }
    _ConstructorDataEnd =  {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = _BridgePrefix .. "_END_PREFAB",
		FillerList = {
			_BridgePrefix .. "_TILING_PART"
		},
		BasementScale = 2
    }
else
    GreatLadder:log("Hello World: game version " .. foundation.getGameVersion())
    _MoverStart = "BUILDING_PART_MOVER_BRIDGE"
    _MoverCore = "BUILDING_PART_MOVER"
    _ConstructorDataStart =  {
		DataType = "BUILDING_CONSTRUCTOR_SLOPE",
		CoreObjectPrefab = _BridgePrefix .. "_START_PREFAB",
		SlopePartList = {
			_BridgePrefix .. "_SLOPE_START_PART"
		},
		CoreBasementPartList = {
			_BridgePrefix .. "_TILING_PART"
		},
		UpperAttachType = ATTACH_NODE_TYPE.RIGHT,
		LowerAttachType = ATTACH_NODE_TYPE.LEFT
    }
    _ConstructorDataEnd = {
		DataType = "BUILDING_CONSTRUCTOR_SLOPE",
		CoreObjectPrefab = _BridgePrefix .. "_END_PREFAB",
		SlopePartList = {
			_BridgePrefix .. "_SLOPE_END_PART"
		},
		CoreBasementPartList = {
			_BridgePrefix .. "_TILING_PART"
		},
		UpperAttachType = ATTACH_NODE_TYPE.LEFT,
		LowerAttachType = ATTACH_NODE_TYPE.RIGHT,
    } 
end

--------------------------------------------------------------------------
-- Register bridge tiling (the pillar part that extends to the ground)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_TILING_PART",
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _BridgePrefix .. "_TILING_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 0 }
		}
	}
})


-- Register bridge start part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_START_PART",
        BuildingZone = _BridgeBuildingZone,
	Mover = { DataType = _MoverStart },
	ConstructorData = _ConstructorDataStart,
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		}
	}
})

-- Register bridge end part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_END_PART",
        BuildingZone = _BridgeBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER_BRIDGE" },
	ConstructorData = _ConstructorDataEnd,
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		}
	}
})

-- Register bridge start slope part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_SLOPE_START_PART",
        BuildingZone = _BridgeBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = _BridgePrefix .. "_SLOPE_START_PREFAB",
		FillerList = {
			_BridgePrefix .. "_TILING_PART"
		},
		BasementScale = 1
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		}
	}
})

-- Register bridge end slope part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_SLOPE_END_PART",
        BuildingZone = _BridgeBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = _BridgePrefix .. "_SLOPE_END_PREFAB",
		FillerList = {
			_BridgePrefix .. "_TILING_PART"
		},
		BasementScale = 1
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 1 }
		}
	}
})

-- Register bridge center top part
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_CENTER_TOP_PART",
        BuildingZone = _BridgeBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _BridgePrefix .. "_CENTER_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 0 }
		}
	}
})

-- Register the center root part (the scalable part that places multiple center top parts)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_CENTER_CORE_PART",
        BuildingZone = _BridgeBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = _BridgePrefix .. "_CENTER_ROOT_PREFAB",
		EndPart = _BridgePrefix .. "_CENTER_TOP_PART",
		FillerList = {
			_BridgePrefix .. "_TILING_PART"
		},
		BasementScale = 2
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "WOOD", Quantity = 0 }
		}
	}
})

-- Register the core part (the part with the bridge mover)
GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _BridgePrefix .. "_CORE_PART",
	Name = _BridgePrefix .. "_CORE_NAME",
	Description = _BridgePrefix .. "_CORE_DESC",
	Category = "CORE",
        BuildingZone = _BridgeBuildingZone,
	Mover = { DataType = _MoverCore },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BRIDGE",
		StartPart = _BridgePrefix .. "_START_PART",
		EndPart = _BridgePrefix .. "_END_PART",
		FillerList = {
			_BridgePrefix .. "_CENTER_CORE_PART"
		},
		SlopeFillerList = {
			_BridgePrefix .. "_SLOPE_END_PART"
		},
		SlopeStartFillerList = {
			_BridgePrefix .. "_SLOPE_START_PART"
		},
		MinimumScale = 0,
                MinimumHeightAboveGround = 0  
	},
	AssetBuildingFunction = _BridgePrefix .. "_FUNCTION"
})
GreatLadder:register({
		DataType = "BUILDING_FUNCTION_BRIDGE",
                Id = _BridgePrefix .. "_FUNCTION"
})

GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/CenterPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/StartPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/EndPart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/StartSlopePart", { "BRIDGE" })
GreatLadder:configurePrefabFlagList("models/greatLadder3.fbx/Prefab/greatLadder/EndSlopePart", { "BRIDGE" })

-- Override building part components properties (generated by the building asset processor) to add building zones

GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/CenterPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/StartPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/EndPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/StartSlopePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
GreatLadder:registerPrefabComponent("models/greatLadder3.fbx/Prefab/greatLadder/EndSlopePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 0.1, 0.1 }
})
