local GreatLadder = ...

_GreatLadderPrefix = "GREAT_LADDER"
_BridgePrefix = "GL3_BRIDGE"

-- Apply building asset processor
GreatLadder:registerAssetProcessor("models/greatLadder.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})
GreatLadder:registerAssetProcessor("models/greatLadder3.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Register the great ladder monument
local myMonument = {
	Id = _GreatLadderPrefix .. "_MONUMENT",
	Name = _GreatLadderPrefix .. "_NAME",
	Description = _GreatLadderPrefix .. "_DESC",
	BuildingType = "MONUMENT",
	RequiredPartList = {
		-- Necessarily a list of 'MONUMENT_REQUIRED_PART_PAIR', no need to specify the DataType of each element of the list
		{ Category = "CORE", Quantity = 1 }
	},
        IsEditable = true
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    GreatLadder:log("Hello World: game version anterior to 1.6")
    myMonument.DataType = "MONUMENT"
    myMonument.BuildingPartSetList = {
		{
			Name = _GreatLadderPrefix .. "_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _GreatLadderPrefix .. "_ROOT_PART",
                            _BridgePrefix .. "_CORE_PART"
                        }
                 }                                     
    }
    -- Register the Stone Gate Set monument
    GreatLadder:register(myMonument)

    _GreatLadderBuildingZone = { Polygon = polygon.createRectangle( {1, 1} ) } 
    _BridgeBuildingZone = { Polygon = polygon.createRectangle( {0.1, 0.1} ) } 

else
    GreatLadder:log("Hello World: game version " .. foundation.getGameVersion())
    myMonument.DataType = "BUILDING"
    myMonument.AssetCoreBuildingPart = _BridgePrefix .. "_CORE_PART"
    -- Register the Stone Gate Set monument
    GreatLadder:register(myMonument)

    -- Apply building asset processor
    GreatLadder:registerAssetProcessor("models/core.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
    })
    GreatLadder:registerAssetId("models/core.fbx/Prefab/CoreBuildingPart", _GreatLadderPrefix .. "_CORE_BUILDING_PREFAB")
    -- Register the Core part
    GreatLadder:register({
	DataType = "BUILDING_PART",
	Id = _GreatLadderPrefix .. "_CORE_BUILDING_PART",
	Name = _GreatLadderPrefix .. "_CORE_BUILDING_NAME",
	Description = _GreatLadderPrefix .. "_CORE_BUILDING_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _GreatLadderPrefix .. "_CORE_BUILDING_PREFAB"
	},
        IsVisibleWhenBuilt = false
    })

    GreatLadder:register({
        DataType = "BUILDING",
	Id = _GreatLadderPrefix .. "1_MONUMENT",
	Name = _GreatLadderPrefix .. "_NAME",
	Description = _GreatLadderPrefix .. "_DESC",
	BuildingType = "DECORATION",
        AssetCoreBuildingPart = _GreatLadderPrefix .. "_CORE_BUILDING_PART",
        BuildingPartSetList = {
		{
			Name = _GreatLadderPrefix .. "_PARTSETLIST_NAME",
	                BuildingPartList = {
		            _GreatLadderPrefix .. "_ROOT_PART"
                        }
                 }                                     
        },
	RequiredPartList = {
		-- Necessarily a list of 'MONUMENT_REQUIRED_PART_PAIR', no need to specify the DataType of each element of the list
		{ Category = "CORE", Quantity = 1 }
	},
        IsEditable = true
    })

    _GreatLadderBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {1, 1} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
    }}
    _BridgeBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {0.1, 0.1} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
    }}
end

-- Register all great ladder building parts and their properties
GreatLadder:dofile("scripts/buildings.lua")
GreatLadder:dofile("scripts/buildings3.lua")


